@@ -35,10 +35,12 @@
 ## -- 2022-02-24  1.3.5     SY       Introduce new class HyperParamDispatcher
 ## -- 2022-03-02  1.3.6     SY       Refactoring class HyperParamDispatcher
 ## -- 2022-03-02  1.3.7     DA       Class HyperParamDispatcher:correction of method set_values()
+## -- 2022-06-06  1.3.8     MRD      Add additional parameter to Training class, p_env_mode for
+## --                                setting up environment mode
 ## -------------------------------------------------------------------------------------------------
 
 """
-Ver. 1.3.7 (2022-03-02)
+Ver. 1.3.8 (2022-06-06)
 This module provides fundamental machine learning templates, functionalities and properties.
 """
 
@@ -453,7 +455,7 @@ class Scenario (Mode, LoadSave, Plottable):
 
 
         # 1 Setup entire scenario
-        self._model = self._setup(p_mode=self.C_MODE_SIM, p_ada=p_ada, p_logging=p_logging)
+        self._model = self._setup(p_mode=p_mode, p_ada=p_ada, p_logging=p_logging)
         if self._model is None: 
             raise ImplementationError('Please return your ML model in method self._setup()')
 
@@ -1062,6 +1064,13 @@ class Training (Log):
             logging = Log.C_LOG_WE
             self._kwargs['p_logging'] = logging
 
+        # 1.9 Optional environment mode
+        try:
+            env_mode = self._kwargs['p_env_mode']
+        except:
+            env_mode = Mode.C_MODE_SIM
+            self._kwargs['p_env_mode'] = env_mode
+
 
         # 2 Initialization
         super().__init__(p_logging=logging)
@@ -1078,7 +1087,7 @@ class Training (Log):
         # 3 Setup scenario
         if self._hpt is None:
             try:
-                self._scenario = scenario_cls( p_mode=Mode.C_MODE_SIM, 
+                self._scenario = scenario_cls( p_mode=env_mode, 
                                                p_ada=True,
                                                p_cycle_limit=self._cycle_limit,
                                                p_visualize=visualize,
